==> haskell-http-api-data-0.6-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-api-data.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-api-data
version:              0.6
visibility:           public
id:                   http-api-data-0.6-5LnQNakLgRCL3jHz5M5b8Z
key:                  http-api-data-0.6-5LnQNakLgRCL3jHz5M5b8Z
license:              BSD-3-Clause
maintainer:           Nickolay Kudasov <nickolay.kudasov@gmail.com>
author:               Nickolay Kudasov <nickolay.kudasov@gmail.com>
stability:            unstable
homepage:             http://github.com/fizruk/http-api-data
synopsis:
    Converting to/from HTTP API data like URL pieces, headers and query parameters.

description:
    This package defines typeclasses used for converting Haskell data types to and from HTTP API data.

    Please see README.md

category:             Web
abi:                  0f1d9cee2b3f5b948516c915514709a5
exposed:              True
exposed-modules:
    Web.FormUrlEncoded Web.HttpApiData Web.Internal.FormUrlEncoded
    Web.Internal.HttpApiData

import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-api-data-0.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-api-data-0.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-api-data-0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-api-data
hs-libraries:         HShttp-api-data-0.6-5LnQNakLgRCL3jHz5M5b8Z
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    cookie-0.4.6-GZOZqzUDn152OuhEYvht8s
    hashable-1.4.4.0-1zcla4qwUGf6ADT5z5m7Nb
    http-types-0.12.4-IhtLMXP6VlH4EvGJYn8uz7
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C text-2.0.2
    text-iso8601-0.1.1-LO5fWUUb4XJ6j4jVPiAHgg
    time-compat-1.9.6.1-2ls2GASKJ6z1bA0uZKKYYa transformers-0.5.6.2
    unordered-containers-0.2.20-5ChD9TF8iAH5uLARI0QLMz
    uuid-types-1.0.6-EhGDdLa78kyAYHENLtQBIX

haddock-interfaces:
    /usr/share/doc/haskell-http-api-data/html/http-api-data.haddock

haddock-html:         /usr/share/doc/haskell-http-api-data/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-api-data-0.6-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-api-data.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-api-data
version:              0.6
visibility:           public
id:                   http-api-data-0.6-BWm1WX69clyImIH09L510u
key:                  http-api-data-0.6-BWm1WX69clyImIH09L510u
license:              BSD-3-Clause
maintainer:           Nickolay Kudasov <nickolay.kudasov@gmail.com>
author:               Nickolay Kudasov <nickolay.kudasov@gmail.com>
stability:            unstable
homepage:             http://github.com/fizruk/http-api-data
synopsis:
    Converting to/from HTTP API data like URL pieces, headers and query parameters.

description:
    This package defines typeclasses used for converting Haskell data types to and from HTTP API data.

    Please see README.md

category:             Web
abi:                  1322cd496dd70fa3b06936f8e572896f
exposed:              True
exposed-modules:
    Web.FormUrlEncoded Web.HttpApiData Web.Internal.FormUrlEncoded
    Web.Internal.HttpApiData

import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-api-data-0.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-api-data-0.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-api-data-0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-api-data
hs-libraries:         HShttp-api-data-0.6-BWm1WX69clyImIH09L510u
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    cookie-0.4.6-GZOZqzUDn152OuhEYvht8s
    hashable-1.4.4.0-9uPnQxUdwOnCZlD9EiHqMs
    http-types-0.12.4-1Pq1Zy5bmQBJRy3r5PsBE
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C text-2.0.2
    text-iso8601-0.1.1-4XCYvSlYefGEuzCoRJoZd7
    time-compat-1.9.6.1-5MK3r3NBCMd242g4GYXBwR transformers-0.5.6.2
    unordered-containers-0.2.20-3iRUctzIz2JCUYhLp7SKku
    uuid-types-1.0.6-9qLtwBCTGuhEZmoNW1PHBJ

haddock-interfaces:
    /usr/share/doc/haskell-http-api-data/html/http-api-data.haddock

haddock-html:         /usr/share/doc/haskell-http-api-data/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
